@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,11 +14,13 @@
 #include <QPointer>
 class QTcpServer;
 class QTimer;
-namespace NoteShared {
+namespace NoteShared
+{
 class NotesChangeRecorder;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Session;
 }
 
@@ -45,6 +47,7 @@ private Q_SLOTS:
     void slotItemChanged(const Akonadi::Item &item, const QSet<QByteArray> &set);
 
     void slotCollectionsReceived(const Akonadi::Collection::List &collections);
+
 private:
     void clear();
     Akonadi::Item::List mListItem;
