@@ -1,15 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef SHOWFOLDERNOTESATTRIBUTE_H
 #define SHOWFOLDERNOTESATTRIBUTE_H
 
-#include <AkonadiCore/attribute.h>
 #include "noteshared_export.h"
+#include <AkonadiCore/attribute.h>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT ShowFolderNotesAttribute : public Akonadi::Attribute
 {
 public:
