@@ -13,13 +13,14 @@
 
 #include <QTcpSocket>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NotesNetworkSender : public QObject
 {
     Q_OBJECT
 public:
     explicit NotesNetworkSender(QTcpSocket *socket);
-    ~NotesNetworkSender();
+    ~NotesNetworkSender() override;
 
     void setSenderId(const QString &sender);
     void setNote(const QString &title, const QString &text);
