@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notelistwidget.h"
 #include "attributes/notedisplayattribute.h"
-#include <KMime/KMimeMessage>
 #include "noteutils.h"
+#include <KMime/KMimeMessage>
 
 using namespace NoteShared;
 class NoteShared::NoteListWidgetPrivate
@@ -68,7 +68,7 @@ void NoteListWidget::createItem(const Akonadi::Item &note)
     if (!noteMessage) {
         return;
     }
-    auto *item = new QListWidgetItem(this);
+    auto item = new QListWidgetItem(this);
 
     const KMime::Headers::Subject *const subject = noteMessage->subject(false);
     if (subject) {
