@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,17 +7,18 @@
 #define NOTELISTWIDGET_H
 
 #include "noteshared_export.h"
-#include <QListWidget>
 #include <AkonadiCore/Item>
+#include <QListWidget>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteListWidgetPrivate;
 class NOTESHARED_EXPORT NoteListWidget : public QListWidget
 {
     Q_OBJECT
 public:
     explicit NoteListWidget(QWidget *parent = nullptr);
-    ~NoteListWidget();
+    ~NoteListWidget() override;
 
     void setNotes(const Akonadi::Item::List &notes);
     void addNotes(const Akonadi::Item::List &notes);
@@ -31,9 +32,7 @@ public:
 
 private:
     void createItem(const Akonadi::Item &note);
-    enum listViewData {
-        AkonadiId = Qt::UserRole + 1
-    };
+    enum listViewData { AkonadiId = Qt::UserRole + 1 };
     NoteListWidgetPrivate *const d;
 };
 }
