@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTEDISPLAYCONFIGWIDGET_H
 #define KNOTEDISPLAYCONFIGWIDGET_H
 
-#include <QWidget>
 #include "knotes_export.h"
+#include <QWidget>
 class KColorButton;
 class QCheckBox;
 class QSpinBox;
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteDisplayAttribute;
 }
 class KNOTES_EXPORT KNoteDisplayConfigWidget : public QWidget
@@ -19,7 +20,7 @@ class KNOTES_EXPORT KNoteDisplayConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit KNoteDisplayConfigWidget(bool defaults, QWidget *parent = nullptr);
-    ~KNoteDisplayConfigWidget();
+    ~KNoteDisplayConfigWidget() override;
 
     void load(NoteShared::NoteDisplayAttribute *attr);
     void save(NoteShared::NoteDisplayAttribute *attr);
