@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,8 +9,8 @@
 
 #include <KLocalizedString>
 
-#include <QCheckBox>
 #include <KFontRequester>
+#include <QCheckBox>
 #include <QGridLayout>
 #include <QLabel>
 #include <QSpinBox>
@@ -18,7 +18,7 @@
 KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QGridLayout(this);
+    auto layout = new QGridLayout(this);
 
     QLabel *label_TabSize = new QLabel(i18n("&Tab size:"), this);
     layout->addWidget(label_TabSize, 0, 0, 1, 2);
@@ -29,8 +29,7 @@ KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
     label_TabSize->setBuddy(kcfg_TabSize);
     layout->addWidget(kcfg_TabSize, 0, 2);
 
-    kcfg_AutoIndent = new QCheckBox(i18n("Auto &indent"),
-                                    this);
+    kcfg_AutoIndent = new QCheckBox(i18n("Auto &indent"), this);
     kcfg_AutoIndent->setObjectName(QStringLiteral("kcfg_AutoIndent"));
     layout->addWidget(kcfg_AutoIndent, 1, 0, 1, 2);
 
@@ -43,8 +42,7 @@ KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
 
     kcfg_Font = new KFontRequester(this);
     kcfg_Font->setObjectName(QStringLiteral("kcfg_Font"));
-    kcfg_Font->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,
-                                         QSizePolicy::Fixed));
+    kcfg_Font->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
     layout->addWidget(kcfg_Font, 3, 1, 1, 2);
 
     QLabel *label_TitleFont = new QLabel(i18n("Title font:"), this);
@@ -52,8 +50,7 @@ KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
 
     kcfg_TitleFont = new KFontRequester(this);
     kcfg_TitleFont->setObjectName(QStringLiteral("kcfg_TitleFont"));
-    kcfg_TitleFont->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,
-                                              QSizePolicy::Fixed));
+    kcfg_TitleFont->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
     layout->addWidget(kcfg_TitleFont, 2, 1, 1, 2);
     layout->setRowStretch(4, 1);
 }
