@@ -3,25 +3,15 @@
 
   SPDX-FileCopyrightText: 2002-2003 Daniel Molkentin <molkentin@kde.org>
   SPDX-FileCopyrightText: 2004-2006 Michael Brade <brade@kde.org>
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "knotes_part.h"
-#include "knotes_kontact_plugin_debug.h"
-#include "knoteedit.h"
-#include "knotesadaptor.h"
-#include "knoteseditdialog.h"
-#include "knotesglobalconfig.h"
-#include "knotesiconview.h"
-#include "knotesselectdeletenotesdialog.h"
-#include "knoteswidget.h"
-#include "notesharedglobalconfig.h"
-#include "noteutils.h"
-#include "alarms/notealarmdialog.h"
 #include "akonadi/notesakonaditreemodel.h"
 #include "akonadi/noteschangerecorder.h"
+#include "alarms/notealarmdialog.h"
 #include "attributes/notealarmattribute.h"
 #include "attributes/notedisplayattribute.h"
 #include "attributes/notelockattribute.h"
@@ -30,6 +20,16 @@
 #include "configdialog/knotesimpleconfigdialog.h"
 #include "finddialog/knotefinddialog.h"
 #include "job/createnewnotejob.h"
+#include "knoteedit.h"
+#include "knotes_kontact_plugin_debug.h"
+#include "knotesadaptor.h"
+#include "knoteseditdialog.h"
+#include "knotesglobalconfig.h"
+#include "knotesiconview.h"
+#include "knotesselectdeletenotesdialog.h"
+#include "knoteswidget.h"
+#include "notesharedglobalconfig.h"
+#include "noteutils.h"
 #include "print/knoteprinter.h"
 #include "print/knoteprintobject.h"
 #include "print/knoteprintselectthemedialog.h"
@@ -49,9 +49,9 @@
 
 #include <KActionCollection>
 #include <KCheckableProxyModel>
+#include <KDNSSD/DNSSD/PublicService>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KDNSSD/DNSSD/PublicService>
 
 #include <QApplication>
 #include <QCheckBox>
@@ -76,117 +76,94 @@ KNotesPart::KNotesPart(QObject *parent)
     Akonadi::ControlGui::widgetNeedsAkonadi(widget());
 
     if (KNotesGlobalConfig::self()->autoCreateResourceOnStart()) {
-        auto *creator = new NoteShared::LocalResourceCreator(this);
+        auto creator = new NoteShared::LocalResourceCreator(this);
         creator->createIfMissing();
     }
 
     // create the actions
-    mNewNote = new QAction(QIcon::fromTheme(QStringLiteral("knotes")),
-                           i18nc("@action:inmenu create new popup note", "&New"), this);
+    mNewNote = new QAction(QIcon::fromTheme(QStringLiteral("knotes")), i18nc("@action:inmenu create new popup note", "&New"), this);
     actionCollection()->addAction(QStringLiteral("file_new"), mNewNote);
     connect(mNewNote, &QAction::triggered, this, [this]() {
         newNote();
     });
-    actionCollection()->setDefaultShortcut(mNewNote, QKeySequence(Qt::CTRL + Qt::Key_N));
-    //mNewNote->setHelpText(
+    actionCollection()->setDefaultShortcut(mNewNote, QKeySequence(Qt::CTRL | Qt::Key_N));
+    // mNewNote->setHelpText(
     //            i18nc( "@info:status", "Create a new popup note" ) );
-    mNewNote->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be presented with a dialog where you can add a new popup note."));
+    mNewNote->setWhatsThis(i18nc("@info:whatsthis", "You will be presented with a dialog where you can add a new popup note."));
 
-    mNoteEdit = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")),
-                            i18nc("@action:inmenu", "Edit..."), this);
+    mNoteEdit = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18nc("@action:inmenu", "Edit..."), this);
     actionCollection()->addAction(QStringLiteral("edit_note"), mNoteEdit);
     connect(mNoteEdit, &QAction::triggered, this, [this]() {
         editNote();
     });
-    //mNoteEdit->setHelpText(
+    // mNoteEdit->setHelpText(
     //            i18nc( "@info:status", "Edit popup note" ) );
-    mNoteEdit->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be presented with a dialog where you can modify an existing popup note."));
+    mNoteEdit->setWhatsThis(i18nc("@info:whatsthis", "You will be presented with a dialog where you can modify an existing popup note."));
 
-    mNoteRename = new QAction(QIcon::fromTheme(QStringLiteral("edit-rename")),
-                              i18nc("@action:inmenu", "Rename..."), this);
+    mNoteRename = new QAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18nc("@action:inmenu", "Rename..."), this);
     actionCollection()->setDefaultShortcut(mNoteRename, QKeySequence(Qt::Key_F2));
     actionCollection()->addAction(QStringLiteral("edit_rename"), mNoteRename);
     connect(mNoteRename, &QAction::triggered, this, &KNotesPart::renameNote);
-    //mNoteRename->setHelpText(
+    // mNoteRename->setHelpText(
     //            i18nc( "@info:status", "Rename popup note" ) );
-    mNoteRename->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be presented with a dialog where you can rename an existing popup note."));
+    mNoteRename->setWhatsThis(i18nc("@info:whatsthis", "You will be presented with a dialog where you can rename an existing popup note."));
 
-    mNoteDelete = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
-                              i18nc("@action:inmenu", "Delete"), this);
+    mNoteDelete = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("@action:inmenu", "Delete"), this);
     actionCollection()->addAction(QStringLiteral("edit_delete"), mNoteDelete);
     connect(mNoteDelete, &QAction::triggered, this, &KNotesPart::killSelectedNotes);
     actionCollection()->setDefaultShortcut(mNoteDelete, QKeySequence(Qt::Key_Delete));
-    //mNoteDelete->setHelpText(
+    // mNoteDelete->setHelpText(
     //            i18nc( "@info:status", "Delete popup note" ) );
-    mNoteDelete->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be prompted if you really want to permanently remove "
-              "the selected popup note."));
+    mNoteDelete->setWhatsThis(i18nc("@info:whatsthis",
+                                    "You will be prompted if you really want to permanently remove "
+                                    "the selected popup note."));
 
-    mNotePrint = new QAction(QIcon::fromTheme(QStringLiteral("document-print")),
-                             i18nc("@action:inmenu", "Print Selected Notes..."), this);
+    mNotePrint = new QAction(QIcon::fromTheme(QStringLiteral("document-print")), i18nc("@action:inmenu", "Print Selected Notes..."), this);
     actionCollection()->addAction(QStringLiteral("print_note"), mNotePrint);
     connect(mNotePrint, &QAction::triggered, this, &KNotesPart::slotPrintSelectedNotes);
-    //mNotePrint->setHelpText(
+    // mNotePrint->setHelpText(
     //            i18nc( "@info:status", "Print popup note" ) );
-    mNotePrint->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be prompted to print the selected popup note."));
+    mNotePrint->setWhatsThis(i18nc("@info:whatsthis", "You will be prompted to print the selected popup note."));
 
-    mNotePrintPreview = new QAction(QIcon::fromTheme(QStringLiteral("document-print-preview")),
-                                    i18nc("@action:inmenu", "Print Preview Selected Notes..."), this);
+    mNotePrintPreview =
+        new QAction(QIcon::fromTheme(QStringLiteral("document-print-preview")), i18nc("@action:inmenu", "Print Preview Selected Notes..."), this);
     actionCollection()->addAction(QStringLiteral("print_preview_note"), mNotePrintPreview);
 
     connect(mNotePrintPreview, &QAction::triggered, this, &KNotesPart::slotPrintPreviewSelectedNotes);
 
-    mNoteConfigure = new QAction(QIcon::fromTheme(QStringLiteral("configure")),
-                                 i18n("Note settings..."), this);
+    mNoteConfigure = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Note settings..."), this);
     actionCollection()->addAction(QStringLiteral("configure_note"), mNoteConfigure);
     connect(mNoteConfigure, &QAction::triggered, this, &KNotesPart::slotNotePreferences);
 
-    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("configure")),
-                               i18n("Preferences KNotes..."), this);
+    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Preferences KNotes..."), this);
     actionCollection()->addAction(QStringLiteral("knotes_configure"), act);
     connect(act, &QAction::triggered, this, &KNotesPart::slotPreferences);
 
-    mNoteSendMail = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")),
-                                i18n("Mail..."), this);
+    mNoteSendMail = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("Mail..."), this);
     actionCollection()->addAction(QStringLiteral("mail_note"), mNoteSendMail);
     connect(mNoteSendMail, &QAction::triggered, this, &KNotesPart::slotMail);
 
-    mNoteSendNetwork = new QAction(QIcon::fromTheme(QStringLiteral("network-wired")),
-                                   i18n("Send..."), this);
+    mNoteSendNetwork = new QAction(QIcon::fromTheme(QStringLiteral("network-wired")), i18n("Send..."), this);
     actionCollection()->addAction(QStringLiteral("send_note"), mNoteSendNetwork);
     connect(mNoteSendNetwork, &QAction::triggered, this, &KNotesPart::slotSendToNetwork);
 
-    mNoteSetAlarm = new QAction(QIcon::fromTheme(QStringLiteral("knotes_alarm")),
-                                i18n("Set Alarm..."), this);
+    mNoteSetAlarm = new QAction(QIcon::fromTheme(QStringLiteral("knotes_alarm")), i18n("Set Alarm..."), this);
     actionCollection()->addAction(QStringLiteral("set_alarm"), mNoteSetAlarm);
     connect(mNoteSetAlarm, &QAction::triggered, this, &KNotesPart::slotSetAlarm);
 
-    act = new QAction(QIcon::fromTheme(QStringLiteral("edit-paste")),
-                      i18n("New Note From Clipboard"), this);
+    act = new QAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("New Note From Clipboard"), this);
     actionCollection()->addAction(QStringLiteral("new_note_clipboard"), act);
     connect(act, &QAction::triggered, this, &KNotesPart::slotNewNoteFromClipboard);
 
-    act = new QAction(QIcon::fromTheme(QStringLiteral("document-open")),
-                      i18n("New Note From Text File..."), this);
+    act = new QAction(QIcon::fromTheme(QStringLiteral("document-open")), i18n("New Note From Text File..."), this);
     actionCollection()->addAction(QStringLiteral("new_note_from_text_file"), act);
     connect(act, &QAction::triggered, this, &KNotesPart::slotNewNoteFromTextFile);
 
-    mSaveAs = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")),
-                          i18n("Save As..."), this);
+    mSaveAs = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Save As..."), this);
     actionCollection()->addAction(QStringLiteral("save_note"), mSaveAs);
     connect(mSaveAs, &QAction::triggered, this, &KNotesPart::slotSaveAs);
 
-    mReadOnly = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-locked")),
-                                  i18n("Lock"), this);
+    mReadOnly = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-locked")), i18n("Lock"), this);
     actionCollection()->addAction(QStringLiteral("lock_note"), mReadOnly);
     connect(mReadOnly, &KToggleAction::triggered, this, &KNotesPart::slotUpdateReadOnly);
     mReadOnly->setCheckedState(KGuiItem(i18n("Unlock"), QStringLiteral("object-unlocked")));
@@ -198,17 +175,16 @@ KNotesPart::KNotesPart(QObject *parent)
     mNoteRecorder->changeRecorder()->setSession(session);
     mNoteTreeModel = new NoteShared::NotesAkonadiTreeModel(mNoteRecorder->changeRecorder(), this);
 
-    connect(mNoteTreeModel, &NoteShared::NotesAkonadiTreeModel::rowsInserted,
-            this, &KNotesPart::slotRowInserted);
+    connect(mNoteTreeModel, &NoteShared::NotesAkonadiTreeModel::rowsInserted, this, &KNotesPart::slotRowInserted);
 
-    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemChanged,
-            this, &KNotesPart::slotItemChanged);
+    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemChanged, this, &KNotesPart::slotItemChanged);
 
-    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved,
-            this, &KNotesPart::slotItemRemoved);
+    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved, this, &KNotesPart::slotItemRemoved);
 
-    connect(mNoteRecorder->changeRecorder(), qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Akonadi::ChangeRecorder::collectionChanged),
-            this, &KNotesPart::slotCollectionChanged);
+    connect(mNoteRecorder->changeRecorder(),
+            qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Akonadi::ChangeRecorder::collectionChanged),
+            this,
+            &KNotesPart::slotCollectionChanged);
 
     mSelectionModel = new QItemSelectionModel(mNoteTreeModel);
     mModelProxy = new KCheckableProxyModel(this);
@@ -223,16 +199,14 @@ KNotesPart::KNotesPart(QObject *parent)
     mNotesWidget = new KNotesWidget(this, widget());
 
     mQuickSearchAction = new QAction(i18n("Set Focus to Quick Search"), this);
-    //If change shortcut change in quicksearchwidget->lineedit->setPlaceholderText
-    actionCollection()->setDefaultShortcut(mQuickSearchAction, QKeySequence(Qt::ALT + Qt::Key_Q));
+    // If change shortcut change in quicksearchwidget->lineedit->setPlaceholderText
+    actionCollection()->setDefaultShortcut(mQuickSearchAction, QKeySequence(Qt::ALT | Qt::Key_Q));
     actionCollection()->addAction(QStringLiteral("focus_to_quickseach"), mQuickSearchAction);
     connect(mQuickSearchAction, &QAction::triggered, mNotesWidget, &KNotesWidget::slotFocusQuickSearch);
 
-    connect(mNotesWidget->notesView(), &QListWidget::itemDoubleClicked,
-            this, qOverload<QListWidgetItem *>(&KNotesPart::editNote));
+    connect(mNotesWidget->notesView(), &QListWidget::itemDoubleClicked, this, qOverload<QListWidgetItem *>(&KNotesPart::editNote));
 
-    connect(mNotesWidget->notesView(), &QListWidget::itemSelectionChanged,
-            this, &KNotesPart::slotOnCurrentChanged);
+    connect(mNotesWidget->notesView(), &QListWidget::itemSelectionChanged, this, &KNotesPart::slotOnCurrentChanged);
     slotOnCurrentChanged();
 
     setWidget(mNotesWidget);
@@ -263,11 +237,9 @@ void KNotesPart::slotRowInserted(const QModelIndex &parent, int start, int end)
     for (int i = start; i <= end; ++i) {
         if (mNoteTreeModel->hasIndex(i, 0, parent)) {
             const QModelIndex child = mNoteTreeModel->index(i, 0, parent);
-            Akonadi::Collection parentCollection
-                = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
+            Akonadi::Collection parentCollection = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
             if (parentCollection.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
-                Akonadi::Item item
-                    = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+                Akonadi::Item item = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
                 if (!item.hasPayload<KMime::Message::Ptr>()) {
                     continue;
                 }
@@ -302,11 +274,9 @@ void KNotesPart::printSelectedNotes(bool preview)
 {
     const QList<QListWidgetItem *> lst = mNotesWidget->notesView()->selectedItems();
     if (lst.isEmpty()) {
-        KMessageBox::information(
-            mNotesWidget,
-            i18nc("@info",
-                  "To print notes, first select the notes to print from the list."),
-            i18nc("@title:window", "Print Popup Notes"));
+        KMessageBox::information(mNotesWidget,
+                                 i18nc("@info", "To print notes, first select the notes to print from the list."),
+                                 i18nc("@title:window", "Print Popup Notes"));
         return;
     }
     KNotesGlobalConfig *globalConfig = KNotesGlobalConfig::self();
@@ -334,7 +304,7 @@ void KNotesPart::printSelectedNotes(bool preview)
 
 void KNotesPart::newNote(const QString &name, const QString &text)
 {
-    auto *job = new NoteShared::CreateNewNoteJob(this, widget());
+    auto job = new NoteShared::CreateNewNoteJob(this, widget());
     job->setRichText(KNotesGlobalConfig::self()->richText());
     job->setNote(name, text);
     job->start();
@@ -366,12 +336,14 @@ void KNotesPart::killNote(Akonadi::Item::Id id, bool force)
 {
     KNotesIconViewItem *note = mNotesWidget->notesView()->iconView(id);
     if (note
-        && ((!force && KMessageBox::warningContinueCancelList(
-                 mNotesWidget,
-                 i18nc("@info", "Do you really want to delete this note?"),
-                 QStringList(note->realName()),
-                 i18nc("@title:window", "Confirm Delete"),
-                 KStandardGuiItem::del()) == KMessageBox::Continue) || force)) {
+        && ((!force
+             && KMessageBox::warningContinueCancelList(mNotesWidget,
+                                                       i18nc("@info", "Do you really want to delete this note?"),
+                                                       QStringList(note->realName()),
+                                                       i18nc("@title:window", "Confirm Delete"),
+                                                       KStandardGuiItem::del())
+                 == KMessageBox::Continue)
+            || force)) {
         Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(note->item());
         connect(job, &Akonadi::ItemDeleteJob::result, this, &KNotesPart::slotDeleteNotesFinished);
     }
@@ -389,7 +361,7 @@ QString KNotesPart::name(Akonadi::Item::Id id) const
 
 QString KNotesPart::text(Akonadi::Item::Id id) const
 {
-    //TODO return plaintext ?
+    // TODO return plaintext ?
     KNotesIconViewItem *note = mNotesWidget->notesView()->iconView(id);
     if (note) {
         return note->description();
@@ -436,7 +408,7 @@ void KNotesPart::killSelectedNotes()
     QList<KNotesIconViewItem *> items;
     items.reserve(lst.count());
     for (QListWidgetItem *item : lst) {
-        auto *knivi = static_cast<KNotesIconViewItem *>(item);
+        auto knivi = static_cast<KNotesIconViewItem *>(item);
         items.append(knivi);
     }
 
@@ -454,7 +426,7 @@ void KNotesPart::killSelectedNotes()
             }
         }
         if (!lst.isEmpty()) {
-            auto *job = new Akonadi::ItemDeleteJob(lst);
+            auto job = new Akonadi::ItemDeleteJob(lst);
             connect(job, &Akonadi::ItemDeleteJob::result, this, &KNotesPart::slotDeleteNotesFinished);
         }
     }
@@ -470,15 +442,13 @@ void KNotesPart::slotDeleteNotesFinished(KJob *job)
 
 void KNotesPart::popupRMB(QListWidgetItem *item, const QPoint &pos, const QPoint &globalPos)
 {
-    Q_UNUSED(item);
+    Q_UNUSED(item)
 
-    auto *contextMenu = new QMenu(widget());
+    auto contextMenu = new QMenu(widget());
     if (mNotesWidget->notesView()->itemAt(pos)) {
         contextMenu->addAction(mNewNote);
         const bool uniqueNoteSelected = (mNotesWidget->notesView()->selectedItems().count() == 1);
-        const bool readOnly = uniqueNoteSelected
-                              ? static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly()
-                              : false;
+        const bool readOnly = uniqueNoteSelected ? static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly() : false;
 
         if (uniqueNoteSelected) {
             if (!readOnly) {
@@ -527,7 +497,7 @@ void KNotesPart::editNote(Akonadi::Item::Id id)
 
 void KNotesPart::editNote(QListWidgetItem *item)
 {
-    auto *knotesItem = static_cast<KNotesIconViewItem *>(item);
+    auto knotesItem = static_cast<KNotesIconViewItem *>(item);
     QPointer<KNoteEditDialog> dlg = new KNoteEditDialog(knotesItem->readOnly(), widget());
     dlg->setTitle(knotesItem->realName());
     dlg->setText(knotesItem->description());
@@ -557,14 +527,12 @@ void KNotesPart::editNote()
 
 void KNotesPart::renameNote()
 {
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
 
     const QString oldName = knoteItem->realName();
     bool ok = false;
-    const QString newName
-        = QInputDialog::getText(mNotesWidget, i18nc("@title:window", "Rename Popup Note"),
-                                i18nc("@label:textbox", "New Name:"),
-                                QLineEdit::Normal, oldName, &ok);
+    const QString newName =
+        QInputDialog::getText(mNotesWidget, i18nc("@title:window", "Rename Popup Note"), i18nc("@label:textbox", "New Name:"), QLineEdit::Normal, oldName, &ok);
     if (ok && (newName != oldName)) {
         knoteItem->setIconText(newName);
     }
@@ -583,8 +551,7 @@ void KNotesPart::slotOnCurrentChanged()
     mSaveAs->setEnabled(uniqueNoteSelected);
     mReadOnly->setEnabled(uniqueNoteSelected);
     if (uniqueNoteSelected) {
-        const bool readOnly
-            = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly();
+        const bool readOnly = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly();
         mReadOnly->setChecked(readOnly);
         mNoteEdit->setText(readOnly ? i18n("Show Note...") : i18nc("@action:inmenu", "Edit..."));
     } else {
@@ -597,7 +564,7 @@ void KNotesPart::slotNotePreferences()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog(knoteItem->realName(), widget());
     Akonadi::Item item = knoteItem->item();
     dialog->load(item, knoteItem->isRichText());
@@ -608,7 +575,7 @@ void KNotesPart::slotNotePreferences()
         KMime::Message::Ptr message = item.payload<KMime::Message::Ptr>();
         message->contentType(true)->setMimeType(isRichText ? "text/html" : "text/plain");
         message->assemble();
-        auto *job = new Akonadi::ItemModifyJob(item);
+        auto job = new Akonadi::ItemModifyJob(item);
         connect(job, &Akonadi::ItemModifyJob::result, this, &KNotesPart::slotNoteSaved);
     }
     delete dialog;
@@ -637,7 +604,7 @@ void KNotesPart::slotMail()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     NoteShared::NoteUtils noteUtils;
     noteUtils.sendToMail(widget(), knoteItem->realName(), knoteItem->description());
 }
@@ -647,7 +614,7 @@ void KNotesPart::slotSendToNetwork()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     NoteShared::NoteUtils noteUtils;
     noteUtils.sendToNetwork(widget(), knoteItem->realName(), knoteItem->description());
 }
@@ -671,7 +638,7 @@ void KNotesPart::slotSetAlarm()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
     QPointer<NoteShared::NoteAlarmDialog> dlg = new NoteShared::NoteAlarmDialog(knoteItem->realName(), widget());
     Akonadi::Item item = knoteItem->item();
     if (item.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
@@ -681,8 +648,7 @@ void KNotesPart::slotSetAlarm()
         bool needToModify = true;
         QDateTime dateTime = dlg->alarm();
         if (dateTime.isValid()) {
-            auto *attribute
-                = item.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
+            auto *attribute = item.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
             attribute->setDateTime(dateTime);
         } else {
             if (item.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
@@ -692,7 +658,7 @@ void KNotesPart::slotSetAlarm()
             }
         }
         if (needToModify) {
-            auto *job = new Akonadi::ItemModifyJob(item);
+            auto job = new Akonadi::ItemModifyJob(item);
             connect(job, &Akonadi::ItemModifyJob::result, this, &KNotesPart::slotNoteSaved);
         }
     }
@@ -718,7 +684,7 @@ void KNotesPart::slotSaveAs()
     if (!mNotesWidget->notesView()->currentItem()) {
         return;
     }
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    auto knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
 
     QStringList filters;
     if (knoteItem->isRichText()) {
@@ -727,8 +693,7 @@ void KNotesPart::slotSaveAs()
     filters << i18n("Plain text (*.txt)");
 
     QString format;
-    const QString fileName = QFileDialog::getSaveFileName(widget(), i18n("Save As"), QString(),
-                                                          filters.join(QLatin1String(";;")), &format);
+    const QString fileName = QFileDialog::getSaveFileName(widget(), i18n("Save As"), QString(), filters.join(QLatin1String(";;")), &format);
     if (fileName.isEmpty()) {
         return;
     }
@@ -736,11 +701,11 @@ void KNotesPart::slotSaveAs()
 
     QFile file(fileName);
     if (file.exists()
-        && KMessageBox::warningContinueCancel(
-            widget(),
-            i18n("<qt>A file named <b>%1</b> already exists.<br />"
-                 "Are you sure you want to overwrite it?</qt>",
-                 QFileInfo(file).fileName())) != KMessageBox::Continue) {
+        && KMessageBox::warningContinueCancel(widget(),
+                                              i18n("<qt>A file named <b>%1</b> already exists.<br />"
+                                                   "Are you sure you want to overwrite it?</qt>",
+                                                   QFileInfo(file).fileName()))
+            != KMessageBox::Continue) {
         return;
     }
 
@@ -752,7 +717,7 @@ void KNotesPart::slotSaveAs()
             QString htmlStr = doc.toHtml();
             htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""),
                             QStringLiteral("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
-            stream <<  htmlStr;
+            stream << htmlStr;
         } else {
             stream << knoteItem->realName() + QLatin1Char('\n');
             stream << doc.toPlainText();
@@ -766,7 +731,7 @@ void KNotesPart::slotUpdateReadOnly()
     if (!item) {
         return;
     }
-    auto *knoteItem = static_cast<KNotesIconViewItem *>(item);
+    auto knoteItem = static_cast<KNotesIconViewItem *>(item);
 
     const bool readOnly = mReadOnly->isChecked();
 
@@ -806,7 +771,7 @@ void KNotesPart::slotSelectNote(Akonadi::Item::Id id)
 void KNotesPart::slotCollectionChanged(const Akonadi::Collection &col, const QSet<QByteArray> &set)
 {
     if (set.contains("showfoldernotesattribute")) {
-        //qCDebug(KNOTES_KONTACT_PLUGIN_LOG)<<" collection Changed "<<set<<" col "<<col;
+        // qCDebug(KNOTES_KONTACT_PLUGIN_LOG)<<" collection Changed "<<set<<" col "<<col;
         if (col.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
             fetchNotesFromCollection(col);
         } else {
@@ -824,7 +789,7 @@ void KNotesPart::slotCollectionChanged(const Akonadi::Collection &col, const QSe
 
 void KNotesPart::fetchNotesFromCollection(const Akonadi::Collection &col)
 {
-    auto *job = new Akonadi::ItemFetchJob(col);
+    auto job = new Akonadi::ItemFetchJob(col);
     job->fetchScope().fetchFullPayload(true);
     job->fetchScope().fetchAttribute<NoteShared::NoteLockAttribute>();
     job->fetchScope().fetchAttribute<NoteShared::NoteDisplayAttribute>();
@@ -840,7 +805,7 @@ void KNotesPart::slotItemFetchFinished(KJob *job)
         return;
     }
 
-    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
 
     const Akonadi::Item::List items = fetchJob->items();
     for (const Akonadi::Item &item : items) {
@@ -854,16 +819,13 @@ void KNotesPart::slotItemFetchFinished(KJob *job)
 void KNotesPart::slotNewNoteFromTextFile()
 {
     QString text;
-    const QString filename = QFileDialog::getOpenFileName(widget(), i18n("Select Text File"), QString(),
-                                                          QStringLiteral("%1 (*.txt)").arg(i18n("Text File")));
+    const QString filename = QFileDialog::getOpenFileName(widget(), i18n("Select Text File"), QString(), QStringLiteral("%1 (*.txt)").arg(i18n("Text File")));
     if (!filename.isEmpty()) {
         QFile f(filename);
         if (f.open(QIODevice::ReadOnly | QIODevice::Text)) {
             text = QString::fromUtf8(f.readAll());
         } else {
-            KMessageBox::error(widget(),
-                               i18n("Error during open text file: %1", f.errorString()),
-                               i18n("Open Text File"));
+            KMessageBox::error(widget(), i18n("Error during open text file: %1", f.errorString()), i18n("Open Text File"));
             return;
         }
         newNote(i18n("Note from file '%1'", filename), text);
