@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ class KNOTES_EXPORT KNotePrinter : public QObject
     Q_OBJECT
 public:
     explicit KNotePrinter(QObject *parent = nullptr);
-    ~KNotePrinter();
+    ~KNotePrinter() override;
 
     void setDefaultFont(const QFont &font);
     Q_REQUIRED_RESULT QFont defaultFont() const;
@@ -29,6 +29,7 @@ public:
 
 private Q_SLOTS:
     void slotPrinterPage(QPrinter *printer);
+
 private:
     void print(QPrinter &printer, const QString &htmlText);
     void doPrint(const QString &content, const QString &dialogCaption);
